pub enum AddFilterResponse {
Ok(String),
LimitReached(LimitReachedResult),
}Expand description
Response returned by statement_unstable_add_filter.
Variants
Ok(String)
Filter was added and the string contains its filter id.
LimitReached(LimitReachedResult)
Filter could not be added because the subscription reached its limit.
Implementations
Sourceimpl AddFilterResponse
impl AddFilterResponse
Sourcepub fn limit_reached() -> Self
pub fn limit_reached() -> Self
Returns the limit-reached response.