RejectionReason

Enum RejectionReason 

pub enum RejectionReason {
    DataTooLarge {
        submitted_size: usize,
        available_size: usize,
    },
    ChannelPriorityTooLow {
        submitted_expiry: u64,
        min_expiry: u64,
    },
    AccountFull {
        submitted_expiry: u64,
        min_expiry: u64,
    },
    StoreFull,
    NoAllowance,
}
Reason why a statement was rejected from the store.

Variants



DataTooLarge

Statement data exceeds the maximum allowed size for the account.

Fields

submitted_size: usize

The size of the submitted statement data.

available_size: usize

Still available data size for the account.



ChannelPriorityTooLow

Attempting to replace a channel message with lower or equal expiry.

Fields

submitted_expiry: u64

The expiry of the submitted statement.

min_expiry: u64

The minimum expiry of the existing channel message.



AccountFull

Account reached its statement limit and submitted expiry is too low to evict existing.

Fields

submitted_expiry: u64

The expiry of the submitted statement.

min_expiry: u64

The minimum expiry of the existing statement.



StoreFull

The global statement store is full and cannot accept new statements.



NoAllowance

Account has no allowance set.

Implementations

Source

impl RejectionReason

pub fn label(&self) -> &'static str

Returns a short string label suitable for use in metrics.