pub enum SubmitRejectionReason {
DataTooLarge {
submitted_size: usize,
available_size: usize,
},
ChannelPriorityTooLow {
submitted_expiry: u64,
min_expiry: u64,
},
AccountFull {
submitted_expiry: u64,
min_expiry: u64,
},
StoreFull,
NoAllowance,
}Expand description
Rejection reason as exposed by the spec-v2 statement_unstable_submit RPC.
Variants
DataTooLarge
Statement data exceeds the maximum allowed size for the account.
Fields
ChannelPriorityTooLow
Attempting to replace a channel message with lower or equal expiry.
Fields
AccountFull
Account reached its statement limit and submitted expiry is too low to evict existing.
Fields
StoreFull
The global statement store is full and cannot accept new statements.
NoAllowance
Account has no allowance set.