Crate sp_statement_store

Crate sp_statement_store 

A crate which contains statement-store primitives.

Re-exports

pub use store_api::StatementSource;

Modules

ed25519
Statement-store specific ed25519 crypto primitives.
runtime_api
Runtime support for the statement store.

Structs

Statement
Statement structure.
StatementAllowance
Statement allowance limits for an account.
Topic
Statement topic.

Enums

Error
Statement store error.
Field
Statement attributes. Each statement is a list of 0 or more fields. Fields may only appear once and in the order declared here.
FilterDecision
Decision returned by the filter used in StatementStore::statements_by_hashes.
InvalidReason
Reason why a statement failed validation.
OptimizedTopicFilter
Topic filter for statement subscriptions, optimized for matching.
Proof
Statement proof.
RejectionReason
Reason why a statement was rejected from the store.
SignatureVerificationResult
Result returned by Statement::verify_signature
StatementEvent
An item returned by the statement subscription stream.
SubmitResult
Statement submission outcome
TopicFilter
Filter for subscribing to statements with different topics.

Constants

MAX_ANY_TOPICS
MatchAny allows to provide a list of topics match against. This is the maximum number of topics allowed.
MAX_TOPICS
Total number of topic fields allowed in a statement and in MatchAll filters.
STATEMENT_ALLOWANCE_PREFIX
Storage key prefix for per-account statement allowances.

Traits

StatementStore
Statement store API.

Functions

decrease_allowance_by
Decrease the statement allowance by the given amount.
get_allowance
Get the statement allowance for the given account.
hash_encoded
Returns blake2-256 hash for the encoded statement.
increase_allowance_by
Increase the statement allowance by the given amount.
statement_allowance_key
Constructs a per-account statement allowance storage key.

Type Aliases

AccountId
Account id
BlockHash
Block hash.
Channel
Statement channel.
DecryptionKey
Decryption key identifier.
Hash
Statement hash.
Result
Result type for Error