A crate which contains statement-store primitives.
Re-exports
pub use store_api::StatementSource;
Modules
- ed25519
- Statement-store specific ed25519 crypto primitives.
- runtime_
api - Runtime support for the statement store.
Structs
- Statement
- Statement structure.
- Statement
Allowance - Statement allowance limits for an account.
- Topic
- Statement topic.
Enums
- Error
- Statement store error.
- Field
- Statement attributes. Each statement is a list of 0 or more fields. Fields may only appear once and in the order declared here.
- Filter
Decision - Decision returned by the filter used in
StatementStore::statements_by_hashes. - Invalid
Reason - Reason why a statement failed validation.
- Optimized
Topic Filter - Topic filter for statement subscriptions, optimized for matching.
- Proof
- Statement proof.
- Rejection
Reason - Reason why a statement was rejected from the store.
- Signature
Verification Result - Result returned by
Statement::verify_signature - Statement
Event - An item returned by the statement subscription stream.
- Submit
Result - Statement submission outcome
- Topic
Filter - Filter for subscribing to statements with different topics.
Constants
- MAX_
ANY_ TOPICS MatchAnyallows to provide a list of topics match against. This is the maximum number of topics allowed.- MAX_
TOPICS - Total number of topic fields allowed in a statement and in
MatchAllfilters. - STATEMENT_
ALLOWANCE_ PREFIX - Storage key prefix for per-account statement allowances.
Traits
- Statement
Store - Statement store API.
Functions
- decrease_
allowance_ by - Decrease the statement allowance by the given amount.
- get_
allowance - Get the statement allowance for the given account.
- hash_
encoded - Returns blake2-256 hash for the encoded statement.
- increase_
allowance_ by - Increase the statement allowance by the given amount.
- statement_
allowance_ key - Constructs a per-account statement allowance storage key.