pub struct Statement { /* private fields */ }Expand description
Statement structure.
Implementations
Sourceimpl Statement
impl Statement
Sourcepub fn new_with_proof(proof: Proof) -> Statement
pub fn new_with_proof(proof: Proof) -> Statement
Create a new statement with a proof.
Sourcepub fn sign_sr25519_public(&mut self, key: &Public) -> bool
pub fn sign_sr25519_public(&mut self, key: &Public) -> bool
Sign with a key that matches given public key in the keystore.
Returns true if signing worked (private key present etc).
NOTE: This can only be called from the runtime.
Sourcepub fn sign_sr25519_private(&mut self, key: &Pair)
pub fn sign_sr25519_private(&mut self, key: &Pair)
Sign with a given private key and add the signature proof field.
Sourcepub fn sign_ed25519_public(&mut self, key: &Public) -> bool
pub fn sign_ed25519_public(&mut self, key: &Public) -> bool
Sign with a key that matches given public key in the keystore.
Returns true if signing worked (private key present etc).
NOTE: This can only be called from the runtime.
Sourcepub fn sign_ed25519_private(&mut self, key: &Pair)
pub fn sign_ed25519_private(&mut self, key: &Pair)
Sign with a given private key and add the signature proof field.
Sourcepub fn sign_ecdsa_public(&mut self, key: &Public) -> bool
pub fn sign_ecdsa_public(&mut self, key: &Public) -> bool
Sign with a key that matches given public key in the keystore.
Returns true if signing worked (private key present etc).
NOTE: This can only be called from the runtime.
Returns true if signing worked (private key present etc).
NOTE: This can only be called from the runtime.
Sourcepub fn sign_ecdsa_private(&mut self, key: &Pair)
pub fn sign_ecdsa_private(&mut self, key: &Pair)
Sign with a given private key and add the signature proof field.
Sourcepub fn verify_signature(&self) -> SignatureVerificationResult
pub fn verify_signature(&self) -> SignatureVerificationResult
Check proof signature, if any.
Sourcepub fn decryption_key(&self) -> Option<DecryptionKey>
pub fn decryption_key(&self) -> Option<DecryptionKey>
Returns decryption key if any.
Sourcepub fn account_id(&self) -> Option<AccountId>
pub fn account_id(&self) -> Option<AccountId>
Get proof account id, if any
Sourcepub fn get_expiration_timestamp_secs(&self) -> u32
pub fn get_expiration_timestamp_secs(&self) -> u32
Get expiration timestamp in seconds.
The expiration timestamp in seconds is stored in the most significant 32 bits of the expiry field.
Sourcepub fn remove_proof(&mut self)
pub fn remove_proof(&mut self)
Remove the proof of this statement.
Sourcepub fn set_proof(&mut self, proof: Proof)
pub fn set_proof(&mut self, proof: Proof)
Set statement proof. Any existing proof is overwritten.
Sourcepub fn set_expiry(&mut self, expiry: u64)
pub fn set_expiry(&mut self, expiry: u64)
Set statement expiry.
Sourcepub fn set_expiry_from_parts(
&mut self,
expiration_timestamp_secs: u32,
sequence_number: u32,
)
pub fn set_expiry_from_parts( &mut self, expiration_timestamp_secs: u32, sequence_number: u32, )
Set statement expiry from its parts. See Statement::expiry for details on the format.
Sourcepub fn set_channel(&mut self, channel: Channel)
pub fn set_channel(&mut self, channel: Channel)
Set statement channel.
Sourcepub fn set_topic(&mut self, index: usize, topic: Topic)
pub fn set_topic(&mut self, index: usize, topic: Topic)
Set topic by index. Does noting if index is over MAX_TOPICS.
Sourcepub fn set_decryption_key(&mut self, key: DecryptionKey)
pub fn set_decryption_key(&mut self, key: DecryptionKey)
Set decryption key.
Sourcepub fn set_plain_data(&mut self, data: Vec<u8>)
pub fn set_plain_data(&mut self, data: Vec<u8>)
Set unencrypted statement data.